summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--gnu/packages/configuration-management.scm42
1 files changed, 17 insertions, 25 deletions
diff --git a/gnu/packages/configuration-management.scm b/gnu/packages/configuration-management.scm
index 66ce87f944..6d81f0dcac 100644
--- a/gnu/packages/configuration-management.scm
+++ b/gnu/packages/configuration-management.scm
@@ -81,47 +81,37 @@
                           "secretlastpass.txt"
                           "secretonepassword.txt"
                           "secretpass.txt"))))
-          ;; FIXME: Pattern embedded: cannot embed directory embedded:
-          ;; contains no embeddable files.
+          ;; TODO: Implement it in go-build-system.
           ;;
           ;; This happens due to Golang can't determine the valid directory of
           ;; the module which is sourced during setup environment phase, but
           ;; easy resolved after coping to expected directory "vendor" within
           ;; the current package, see details in Golang source:
           ;;
           ;; - URL: <https://github.com/golang/go/blob/>
           ;; - commit: 82c14346d89ec0eeca114f9ca0e88516b2cda454
           ;; - file: src/cmd/go/internal/load/pkg.go#L2059
-          (add-before 'build 'copy-input-to-vendor-directory
-            (lambda* (#:key import-path #:allow-other-keys)
-              (with-directory-excursion (string-append "src/" import-path)
-                (mkdir "vendor")
-                (copy-recursively
-                 (string-append
-                  #$(this-package-native-input "go-github-com-charmbracelet-glamour")
-                  "/src/github.com")
-                 "vendor/github.com")
-                (copy-recursively
-                 (string-append
-                  #$(this-package-native-input "go-github-com-alecthomas-chroma-v2")
-                  "/src/github.com")
-                 "vendor/github.com"))))
-          (add-before 'install 'remove-vendor-directory
-            (lambda* (#:key import-path #:allow-other-keys)
-              (with-directory-excursion (string-append "src/" import-path)
-                (delete-file-recursively "vendor")))))))
+          (add-after 'unpack 'fix-embed-files
+            (lambda _
+              (for-each (lambda (file)
+                          (let ((file-store-path (readlink file)))
+                            (delete-file file)
+                            (copy-recursively file-store-path file)))
+                        (find-files "src" (string-append "\\.xml$"))))))))
     (native-inputs
-     (list go-github-com-alecthomas-chroma-v2
+     (list go-github-com-masterminds-sprig-v3
            go-github-com-bmatcuk-doublestar-v2
            go-github-com-charmbracelet-glamour
            go-github-com-coreos-go-semver
            go-github-com-go-git-go-git-v5
            go-github-com-google-go-github-v33
            go-github-com-google-renameio
-           go-github-com-masterminds-sprig-v3
+           go-github-com-muesli-combinator
            go-github-com-pelletier-go-toml
            go-github-com-pkg-diff
            go-github-com-rogpeppe-go-internal
+           go-github-com-rs-zerolog
            go-github-com-sergi-go-diff
            go-github-com-spf13-cobra
            go-github-com-spf13-viper
@@ -132,10 +122,12 @@
            go-github-com-twpayne-go-xdg-v3
            go-github-com-zalando-go-keyring
            go-go-etcd-io-bbolt
+           go-go-uber-org-multierr
            go-golang-org-x-oauth2
            go-golang-org-x-sys
            go-golang-org-x-term
            go-gopkg-in-yaml-v2
+           go-gopkg-in-yaml-v3
            go-howett-net-plist))
     (home-page "https://www.chezmoi.io/")
     (synopsis "Personal configuration files manager")
@@ -81,47 +81,37 @@
           ;;
           ;; This happens due to Golang can't determine the valid directory of
-          ;; the module which is sourced during setup environment phase, but
-          ;; easy resolved after coping to expected directory "vendor" within
-          ;; the current package, see details in Golang source:
+          ;; the module of embed file which is symlinked during setup
+          ;; environment phase, but easy resolved after coping file from the
+          ;; store to the build directory of the current package, see details
+          ;; in Golang source:
           ;;
           ;; - URL: <https://github.com/golang/go/blob/>